==> fuchsia-discoveries-0.0.2-project.tar.gz: fuchsia-discoveries-0.0.2/bluetooth/src/main/java/org/ow2/chameleon/fuchsia/discovery/bluetooth/BluetoothConstants.java <==
/*
 * Copyright 2013 OW2 Chameleon
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.chameleon.fuchsia.discovery.bluetooth;

/*
 * #%L
 * OW2 Chameleon - Fuchsia Discovery Bluetooth
 * %%
 * Copyright (C) 2009 - 2014 OW2 Chameleon
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

public class BluetoothConstants {
    public static final String BLUETOOTH_DEVICE_ADDRESS = "bluetooth.device.address";

    public static final String BLUETOOTH_DEVICE_FRIENDLYNAME = "bluetooth.device.friendlyname";

    public static final String BLUETOOTH_CLASS_MAJORDEVICE = "bluetooth.class.majordevice";

    public static final String BLUETOOTH_CLASS_MINORDEVICE = "bluetooth.class.minordevice";

    public static final String BLUETOOTH_CLASS_SERVICE = "bluetooth.class.service";
}

==> fuchsia-discoveries-0.0.3-project.tar.gz: fuchsia-discoveries-0.0.3/bluetooth/src/main/java/org/ow2/chameleon/fuchsia/discovery/bluetooth/BluetoothConstants.java <==
/*
 * Copyright 2013 OW2 Chameleon
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.chameleon.fuchsia.discovery.bluetooth;

/*
 * #%L
 * OW2 Chameleon - Fuchsia Discovery Bluetooth
 * %%
 * Copyright (C) 2009 - 2014 OW2 Chameleon
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

public final class BluetoothConstants {
    public static final String BLUETOOTH_DEVICE_ADDRESS = "bluetooth.device.address";

    public static final String BLUETOOTH_DEVICE_FRIENDLYNAME = "bluetooth.device.friendlyname";

    public static final String BLUETOOTH_CLASS_MAJORDEVICE = "bluetooth.class.majordevice";

    public static final String BLUETOOTH_CLASS_MINORDEVICE = "bluetooth.class.minordevice";

    public static final String BLUETOOTH_CLASS_SERVICE = "bluetooth.class.service";

    private BluetoothConstants() {
        // private constructor
    }
}
